@@ -28,6 +28,7 @@ class QgsProcessingProvider;
 class QgsProcessingAlgorithm;
 class QgsProcessingToolboxModelGroupNode;
 class QgsProcessingRecentAlgorithmLog;
+class QgsProcessingFavoriteAlgorithmManager;
 
 ///@cond PRIVATE
 
@@ -55,6 +56,8 @@ class GUI_EXPORT QgsProcessingToolboxModelNode : public QObject
         sipType = sipType_QgsProcessingToolboxModelAlgorithmNode;
       else if ( node->nodeType() == QgsProcessingToolboxModelNode::NodeType::Recent )
         sipType = sipType_QgsProcessingToolboxModelRecentNode;
+      else if ( node->nodeType() == QgsProcessingToolboxModelNode::NodeType::Favorite )
+        sipType = sipType_QgsProcessingToolboxModelFavoriteNode;
     }
     else
       sipType = 0;
@@ -72,6 +75,7 @@ class GUI_EXPORT QgsProcessingToolboxModelNode : public QObject
       Group SIP_MONKEYPATCH_COMPAT_NAME( NodeGroup ), //!< Group node
       Algorithm SIP_MONKEYPATCH_COMPAT_NAME( NodeAlgorithm ), //!< Algorithm node
       Recent SIP_MONKEYPATCH_COMPAT_NAME( NodeRecent ), //!< Recent algorithms node
+      Favorite, //!< Favorites algorithms node, since QGIS 3.40
     };
     Q_ENUM( NodeType )
     // *INDENT-ON*
@@ -143,15 +147,30 @@ class GUI_EXPORT QgsProcessingToolboxModelRecentNode : public QgsProcessingToolb
 
   public:
 
-    /**
-     * Constructor for QgsProcessingToolboxModelRecentNode.
-     */
     QgsProcessingToolboxModelRecentNode() = default;
 
     NodeType nodeType() const override { return NodeType::Recent; }
 
 };
 
+/**
+ * \brief Processing toolbox model node corresponding to the favorite algorithms group
+ * \ingroup gui
+ * \warning Not part of stable API and may change in future QGIS releases.
+ * \since QGIS 3.40
+ */
+class GUI_EXPORT QgsProcessingToolboxModelFavoriteNode : public QgsProcessingToolboxModelNode
+{
+    Q_OBJECT
+
+  public:
+
+    QgsProcessingToolboxModelFavoriteNode() = default;
+
+    NodeType nodeType() const override { return NodeType::Favorite; }
+
+};
+
 /**
  * \brief Processing toolbox model node corresponding to a Processing provider.
  * \ingroup gui
@@ -312,9 +331,13 @@ class GUI_EXPORT QgsProcessingToolboxModel : public QAbstractItemModel
      *
      * If \a recentLog is specified then it will be used to create a "Recently used" top
      * level group containing recently used algorithms.
+     *
+     * If \a favoriteManager is specified then it will be used to create a "Favorites" top
+     * level group containing favorite algorithms. Since QGIS 3.40
      */
     QgsProcessingToolboxModel( QObject *parent SIP_TRANSFERTHIS = nullptr, QgsProcessingRegistry *registry = nullptr,
-                               QgsProcessingRecentAlgorithmLog *recentLog = nullptr );
+                               QgsProcessingRecentAlgorithmLog *recentLog = nullptr,
+                               QgsProcessingFavoriteAlgorithmManager *favoriteManager = nullptr );
 
     Qt::ItemFlags flags( const QModelIndex &index ) const override;
     QVariant data( const QModelIndex &index, int role = Qt::DisplayRole ) const override;
@@ -388,10 +411,16 @@ class GUI_EXPORT QgsProcessingToolboxModel : public QAbstractItemModel
      */
     void recentAlgorithmAdded();
 
+    /**
+     * Emitted whenever favorite algorithms are added to the model.
+     */
+    void favoriteAlgorithmAdded();
+
   private slots:
 
     void rebuild();
     void repopulateRecentAlgorithms( bool resetting = false );
+    void repopulateFavoriteAlgorithms( bool resetting = false );
     void providerAdded( const QString &id );
     void providerRemoved( const QString &id );
 
@@ -399,9 +428,11 @@ class GUI_EXPORT QgsProcessingToolboxModel : public QAbstractItemModel
 
     QPointer< QgsProcessingRegistry > mRegistry;
     QPointer< QgsProcessingRecentAlgorithmLog > mRecentLog;
+    QPointer< QgsProcessingFavoriteAlgorithmManager > mFavoriteManager;
 
     std::unique_ptr< QgsProcessingToolboxModelGroupNode > mRootNode;
     QgsProcessingToolboxModelRecentNode *mRecentNode = nullptr;
+    QgsProcessingToolboxModelFavoriteNode *mFavoriteNode = nullptr;
 
     void addProvider( QgsProcessingProvider *provider );
 
@@ -458,10 +489,14 @@ class GUI_EXPORT QgsProcessingToolboxProxyModel: public QSortFilterProxyModel
      *
      * If \a recentLog is specified then it will be used to create a "Recently used" top
      * level group containing recently used algorithms.
+     *
+     * If \a favoriteManager is specified then it will be used to create a "Favorites" top
+     * level group containing favorite algorithms. SInce QGIS 3.40
      */
     explicit QgsProcessingToolboxProxyModel( QObject *parent SIP_TRANSFERTHIS = nullptr,
         QgsProcessingRegistry *registry = nullptr,
-        QgsProcessingRecentAlgorithmLog *recentLog = nullptr );
+        QgsProcessingRecentAlgorithmLog *recentLog = nullptr,
+        QgsProcessingFavoriteAlgorithmManager *favoriteManager = nullptr );
 
     /**
      * Returns the underlying source Processing toolbox model.
